/**
 * Copyright (C) 2010 Cloudfarming <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.geoviewer.wms;

import java.beans.IntrospectionException;
import java.io.IOException;
import java.util.Arrays;
import java.util.List;
import org.geotools.data.ows.Layer;
import org.geotools.data.wms.WMSUtils;
import org.geotools.data.wms.WebMapServer;
import org.geotools.ows.ServiceException;
import org.openide.nodes.ChildFactory;
import org.openide.nodes.Node;
import org.openide.util.Exceptions;

/**
 *
 * @author Timon Veenstra
 */
public class LayerNodeFactory extends ChildFactory<Layer> {

    private final WmsServer wmsServer;

    public LayerNodeFactory(WmsServer wmsServer) {
        this.wmsServer = wmsServer;
    }

    @Override
    protected boolean createKeys(List<Layer> toPopulate) {
        try {
            WebMapServer wms = new WebMapServer(wmsServer.getUrl());
            toPopulate.addAll(Arrays.asList(WMSUtils.getNamedLayers(wms.getCapabilities())));

        } catch (IOException ex) {
            Exceptions.printStackTrace(ex);
        } catch (ServiceException ex) {
            Exceptions.printStackTrace(ex);
        }
        return true;
    }

    @Override
    protected Node createNodeForKey(Layer key) {
        try {
            return new LayerNode(key);
        } catch (IntrospectionException ex) {
            Exceptions.printStackTrace(ex);
        }
        return null;
    }
    
    
}
